#include "FEM.h"

using namespace std;

//=========================================================
//=========================================================
//! main program
int main () {
    
  try{      
    
    TriangMesh mesh;
    mesh.loadFromOBJ( "square_small.obj" );
    
    cerr << "Mesh has " << mesh.getNumberOfNodes() << " nodes and " << mesh.getNumberOfFaces() << " triangles." << endl;
    
    // run over all triangles
    for( int i = 0; i < mesh.getNumberOfFaces(); i++ ){
      cerr << i << "th triangle has area " << mesh.getArea( i ) << endl;
      // run over three nodes of current triangle
      for( int j = 0; j < 3; j++ ){
        // get node indices of node
        int idx = mesh.getGlobalIdx( i, j );
        cerr << j << "th node of triangle " << i << " has global idx " << idx;
	cerr << " and position ( " << mesh.getVertexCoord( idx, 0) << ", " << mesh.getVertexCoord( idx, 1 ) << " )" << endl;
      }
      cerr << "---------" << endl;
    }
    
    // run over all nodes
    Vector coords;
    for( int i = 0; i < mesh.getNumberOfNodes(); i++ ){
      if( mesh.isBoundaryNode(i) ){
	mesh.getVertexCoord( i, coords );
	cerr << i << "th node is boundary node with position: ";
	coords.print();
      }
    }
    
    // plotting
    Vector constVec( mesh.getNumberOfNodes() );
    constVec.setAll( 1. );
    plotPNG( mesh, constVec, "plotTest.png" ); 
    
    

  
  }
  catch ( const char* exc ){
    cerr << "Exception caught: " << exc << endl;
  }

  return 0;
}